==> view_pager_plugin-1.0.x-dev.tar.gz: view_pager_plugin/src/Plugin/views/pager/PageControl.php <==
<?php

namespace Drupal\view_pager_plugin\Plugin\views\pager;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\views\Attribute\ViewsPager;
use Drupal\views\Plugin\views\pager\SqlBase;

/**
 * The plugin to handle PageControl pager.
 *
 * @ingroup views_pager_plugins
 */
#[ViewsPager(
  id: "PageControl",
  title: new TranslatableMarkup("Page Control"),
  short_title: new TranslatableMarkup("Page Control"),
  help: new TranslatableMarkup("Paged output, Page Control Drupal style"),
  theme: "pager",
  register_theme: FALSE
)]

class PageControl extends SqlBase {

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = [];
    $options['items_first_page'] = ['default' => 5];
    $options['items_other_page'] = ['default' => 6];
    $options['id'] = ['default' => 0];
    $options['tags'] = [
      'contains' => [
        'previous' => ['default' => $this->t('‹ Previous')],
        'next' => ['default' => $this->t('Next ›')],
        'first' => ['default' => $this->t('« First')],
        'last' => ['default' => $this->t('Last »')],
      ],
    ];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {

    $form['items_first_page'] = [
      '#title' => $this->t('Items for the first page'),
      '#type' => 'number',
      '#min' => 0,
      '#description' => $this->t('Set items per page'),
      '#default_value' => $this->options['items_first_page'],
    ];

    $form['items_other_page'] = [
      '#title' => $this->t('Items for the other pages'),
      '#type' => 'number',
      '#min' => 0,
      '#description' => $this->t('Set items per page'),
      '#default_value' => $this->options['items_other_page'],
    ];

    $form['id'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Pager ID'),
      '#description' => $this->t("Unless you're experiencing problems with pagers related to this view, you should leave this at 0. If using multiple pagers on one page you may need to set this number to a higher value so as not to conflict within the ?page= array. Large values will add a lot of commas to your URLs, so avoid if possible."),
      '#default_value' => $this->options['id'],
      '#access' => FALSE,
    ];

    $form['tags'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#tree' => TRUE,
      '#title' => $this->t('Pager link labels'),
      '#input' => TRUE,
    ];

    $form['tags']['previous'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Previous page link text'),
      '#default_value' => $this->options['tags']['previous'],
    ];

    $form['tags']['next'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Next page link text'),
      '#default_value' => $this->options['tags']['next'],
    ];
    $form['tags']['first'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First page link text'),
      '#default_value' => $this->options['tags']['first'],
      '#weight' => -10,
    ];

    $form['tags']['last'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Last page link text'),
      '#default_value' => $this->options['tags']['last'],
      '#weight' => 10,
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function validateOptionsForm(&$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    return 'Pages info: First page ' . $this->formatPlural(
      $this->options['items_first_page'],
      '1 item',
      '@count items'
    ) . '; other pages ' . $this->formatPlural(
      $this->options['items_other_page'],
      '1 item',
      '@count items'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $limit = $this->getItemsPerPage();
    $offset_page = 0;
    if ($this->options['items_other_page'] == $this->getItemsPerPage()) {
      $offset_page = $this->options['items_first_page'] - $this->options['items_other_page'];
    }
    $offset = $this->current_page * $this->getItemsPerPage() + $offset_page;
    $this->view->query->setLimit($limit);
    $this->view->query->setOffset($offset);
  }

  /**
   * {@inheritdoc}
   */
  public function preExecute(&$query) {
    $option = $this->getCurrentPage() == 0 ? 'items_first_page' : 'items_other_page';
    $this->setItemsPerPage($this->options[$option]);
  }

  /**
   * {@inheritdoc}
   */
  public function getPagerTotal() {
    $math = $this->total_items - $this->options['items_first_page'];
    return ceil($math / $this->options['items_other_page']) + 1;
  }

  /**
   * {@inheritdoc}
   */
  public function getItemsPerPage() {
    if ($this->getCurrentPage() == 0) {
      return $this->options['items_first_page'] ?? 0;
    }
    return $this->options['items_other_page'] ?? 0;
  }

  /**
   * {@inheritdoc}
   */
  public function updatePageInfo() {
    $this->pagerManager->createPager($this->getPagerTotal(), 1, $this->options['id']);
  }

  /**
   * {@inheritdoc}
   */
  public function render($input) {
    // The 0, 1, 3, 4 indexes are correct. See the template_preprocess_pager()
    // documentation.
    $tags = [
      0 => $this->options['tags']['first'],
      1 => $this->options['tags']['previous'],
      3 => $this->options['tags']['next'],
      4 => $this->options['tags']['last'],
    ];

    return [
      '#theme' => $this->themeFunctions(),
      '#tags' => $tags,
      '#element' => $this->options['id'],
      '#pagination_heading_level' => parent::getHeadingLevel(),
      '#parameters' => $input,
      '#quantity' => 5,
      '#route_name' => !empty($this->view->live_preview) ? '<current>' : '<none>',
    ];
  }

}

==> view_pager_plugin-2.0.x-dev.tar.gz: view_pager_plugin/src/Plugin/views/pager/PageControl.php <==
<?php

namespace Drupal\view_pager_plugin\Plugin\views\pager;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\pager\SqlBase;

/**
 * The plugin to handle PageControl pager.
 *
 * @ViewsPager(
 *   id = "pagecontrol",
 *   title = @Translation("Page Control"),
 *   short_title = @Translation("Page Control"),
 *   help = @Translation("Paged output, Page Control Drupal style"),
 *   theme = "pager",
 *   register_theme = FALSE
 * )
 *
 * @ingroup views_pager_plugins
 */
class PageControl extends SqlBase {

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = [];
    $options['items_first_page'] = ['default' => 5];
    $options['items_other_page'] = ['default' => 6];
    $options['id'] = ['default' => 0];
    $options['tags'] = [
      'contains' => [
        'previous' => ['default' => $this->t('‹ Previous')],
        'next' => ['default' => $this->t('Next ›')],
        'first' => ['default' => $this->t('« First')],
        'last' => ['default' => $this->t('Last »')],
      ],
    ];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {

    $form['items_first_page'] = [
      '#title' => $this->t('Items for the first page'),
      '#type' => 'number',
      '#min' => 0,
      '#description' => $this->t('Set items per page'),
      '#default_value' => $this->options['items_first_page'],
    ];

    $form['items_other_page'] = [
      '#title' => $this->t('Items for the other pages'),
      '#type' => 'number',
      '#min' => 0,
      '#description' => $this->t('Set items per page'),
      '#default_value' => $this->options['items_other_page'],
    ];

    $form['id'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Pager ID'),
      '#description' => $this->t("Unless you're experiencing problems with pagers related to this view, you should leave this at 0. If using multiple pagers on one page you may need to set this number to a higher value so as not to conflict within the ?page= array. Large values will add a lot of commas to your URLs, so avoid if possible."),
      '#default_value' => $this->options['id'],
      '#access' => FALSE,
    ];

    $form['tags'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#tree' => TRUE,
      '#title' => $this->t('Pager link labels'),
      '#input' => TRUE,
    ];

    $form['tags']['previous'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Previous page link text'),
      '#default_value' => $this->options['tags']['previous'],
    ];

    $form['tags']['next'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Next page link text'),
      '#default_value' => $this->options['tags']['next'],
    ];
    $form['tags']['first'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First page link text'),
      '#default_value' => $this->options['tags']['first'],
      '#weight' => -10,
    ];

    $form['tags']['last'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Last page link text'),
      '#default_value' => $this->options['tags']['last'],
      '#weight' => 10,
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function validateOptionsForm(&$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    return 'Pages info: First page ' . $this->formatPlural(
      $this->options['items_first_page'],
      '1 item',
      '@count items'
    ) . '; other pages ' . $this->formatPlural(
      $this->options['items_other_page'],
      '1 item',
      '@count items'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $limit = $this->getItemsPerPage();
    $offset_page = 0;
    if ($this->options['items_other_page'] == $this->getItemsPerPage()) {
      $offset_page = $this->options['items_first_page'] - $this->options['items_other_page'];
    }
    $offset = $this->current_page * $this->getItemsPerPage() + $offset_page;
    $this->view->query->setLimit($limit);
    $this->view->query->setOffset($offset);
  }

  /**
   * {@inheritdoc}
   */
  public function preExecute(&$query) {
    $option = $this->getCurrentPage() == 0 ? 'items_first_page' : 'items_other_page';
    $this->setItemsPerPage($this->options[$option]);
  }

  /**
   * {@inheritdoc}
   */
  public function getPagerTotal() {
    $math = $this->total_items - $this->options['items_first_page'];
    return ceil($math / $this->options['items_other_page']) + 1;
  }

  /**
   * {@inheritdoc}
   */
  public function getItemsPerPage() {
    if ($this->getCurrentPage() == 0) {
      return $this->options['items_first_page'] ?? 0;
    }
    return $this->options['items_other_page'] ?? 0;
  }

  /**
   * {@inheritdoc}
   */
  public function updatePageInfo() {
    $this->pagerManager->createPager($this->getPagerTotal(), 1, $this->options['id']);
  }

  /**
   * {@inheritdoc}
   */
  public function render($input) {
    // The 0, 1, 3, 4 indexes are correct. See the template_preprocess_pager()
    // documentation.
    $tags = [
      0 => $this->options['tags']['first'],
      1 => $this->options['tags']['previous'],
      3 => $this->options['tags']['next'],
      4 => $this->options['tags']['last'],
    ];

    return [
      '#theme' => $this->themeFunctions(),
      '#tags' => $tags,
      '#element' => $this->options['id'],
      '#pagination_heading_level' => parent::getHeadingLevel(),
      '#parameters' => $input,
      '#quantity' => 5,
      '#route_name' => !empty($this->view->live_preview) ? '<current>' : '<none>',
    ];
  }

}
